# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_room.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='data_room.proto',
  package='data_room',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0f\x64\x61ta_room.proto\x12\tdata_room\"\xab\x01\n\x08\x44\x61taRoom\x12\n\n\x02id\x18\x01 \x02(\t\x12 \n\x06tables\x18\x02 \x03(\x0b\x32\x10.data_room.Table\x12!\n\x07queries\x18\x03 \x03(\x0b\x32\x10.data_room.Query\x12\x1e\n\x05roles\x18\x04 \x03(\x0b\x32\x0f.data_room.Role\x12\x11\n\tmrenclave\x18\x06 \x01(\t\x12\x1b\n\x13singleExecutionMode\x18\x07 \x01(\x08\"b\n\x05Table\x12\x1f\n\x17sqlCreateTableStatement\x18\x01 \x02(\t\x12\x38\n\x15submissionConstraints\x18\x02 \x03(\x0b\x32\x19.data_room.TimeConstraint\"\x97\x01\n\x05Query\x12\x11\n\tqueryName\x18\x01 \x02(\t\x12\x1a\n\x12sqlSelectStatement\x18\x02 \x02(\t\x12*\n\x0b\x63onstraints\x18\x03 \x03(\x0b\x32\x15.data_room.Constraint\x12\x33\n\x0fprivacySettings\x18\x04 \x01(\x0b\x32\x1a.data_room.PrivacySettings\"\x97\x01\n\x04Role\x12\x10\n\x08roleName\x18\x01 \x02(\t\x12\x12\n\nemailRegex\x18\x02 \x02(\t\x12=\n\x14\x61uthenticationMethod\x18\x03 \x02(\x0b\x32\x1f.data_room.AuthenticationMethod\x12*\n\x0bpermissions\x18\x04 \x03(\x0b\x32\x15.data_room.Permission\"2\n\x0fPrivacySettings\x12\x1f\n\x17minAggregationGroupSize\x18\x01 \x01(\x03\"~\n\x14\x41uthenticationMethod\x12)\n\ntrustedPki\x18\x01 \x02(\x0b\x32\x15.data_room.TrustedPki\x12#\n\x07mailPki\x18\x02 \x01(\x0b\x32\x12.data_room.MailPki\x12\x16\n\x0epasswordSha256\x18\x03 \x01(\t\"%\n\nTrustedPki\x12\x17\n\x0frootCertificate\x18\x01 \x02(\x0c\"\x1e\n\x07MailPki\x12\x13\n\x0brootCaStore\x18\x01 \x02(\x0c\"\xc7\x04\n\nPermission\x12\x41\n\x15submitQueryPermission\x18\x01 \x01(\x0b\x32 .data_room.SubmitQueryPermissionH\x00\x12=\n\x13tableCrudPermission\x18\x02 \x01(\x0b\x32\x1e.data_room.TableCrudPermissionH\x00\x12M\n\x1b\x64\x61taRoomRetrievalPermission\x18\x03 \x01(\x0b\x32&.data_room.DataroomRetrievalPermissionH\x00\x12M\n\x1b\x61uditLogRetrievalPermission\x18\x04 \x01(\x0b\x32&.data_room.AuditLogRetrievalPermissionH\x00\x12W\n retrieveDataRoomStatusPermission\x18\x05 \x01(\x0b\x32+.data_room.RetrieveDataRoomStatusPermissionH\x00\x12S\n\x1eupdateDataRoomStatusPermission\x18\x06 \x01(\x0b\x32).data_room.UpdateDataRoomStatusPermissionH\x00\x12]\n#retrievePublishedDatasetsPermission\x18\x07 \x01(\x0b\x32..data_room.RetrievePublishedDatasetsPermissionH\x00\x42\x0c\n\npermission\"*\n\x15SubmitQueryPermission\x12\x11\n\tqueryName\x18\x01 \x02(\t\"(\n\x13TableCrudPermission\x12\x11\n\ttableName\x18\x01 \x02(\t\"\x1d\n\x1b\x44\x61taroomRetrievalPermission\"\x1d\n\x1b\x41uditLogRetrievalPermission\"\"\n RetrieveDataRoomStatusPermission\" \n\x1eUpdateDataRoomStatusPermission\"%\n#RetrievePublishedDatasetsPermission\"\xd2\x01\n\nConstraint\x12\x13\n\x0b\x64\x65scription\x18\x01 \x02(\t\x12\x31\n\rsqlConstraint\x18\x02 \x01(\x0b\x32\x18.data_room.SqlConstraintH\x00\x12\x33\n\x0etimeConstraint\x18\x03 \x01(\x0b\x32\x19.data_room.TimeConstraintH\x00\x12\x39\n\x11\x64\x61tasetConstraint\x18\x04 \x01(\x0b\x32\x1c.data_room.DatasetConstraintH\x00\x42\x0c\n\nconstraint\"\"\n\rSqlConstraint\x12\x11\n\tstatement\x18\x01 \x02(\t\"3\n\x0eTimeConstraint\x12\x11\n\ttimestamp\x18\x01 \x02(\x03\x12\x0e\n\x06\x62\x65\x66ore\x18\x02 \x02(\x08\"7\n\x11\x44\x61tasetConstraint\x12\r\n\x05table\x18\x01 \x01(\t\x12\x13\n\x0bsubmissions\x18\x02 \x01(\x03'
)




_DATAROOM = _descriptor.Descriptor(
  name='DataRoom',
  full_name='data_room.DataRoom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='data_room.DataRoom.id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tables', full_name='data_room.DataRoom.tables', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queries', full_name='data_room.DataRoom.queries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roles', full_name='data_room.DataRoom.roles', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mrenclave', full_name='data_room.DataRoom.mrenclave', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='singleExecutionMode', full_name='data_room.DataRoom.singleExecutionMode', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=202,
)


_TABLE = _descriptor.Descriptor(
  name='Table',
  full_name='data_room.Table',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sqlCreateTableStatement', full_name='data_room.Table.sqlCreateTableStatement', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submissionConstraints', full_name='data_room.Table.submissionConstraints', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=302,
)


_QUERY = _descriptor.Descriptor(
  name='Query',
  full_name='data_room.Query',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queryName', full_name='data_room.Query.queryName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sqlSelectStatement', full_name='data_room.Query.sqlSelectStatement', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='data_room.Query.constraints', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='privacySettings', full_name='data_room.Query.privacySettings', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=456,
)


_ROLE = _descriptor.Descriptor(
  name='Role',
  full_name='data_room.Role',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='roleName', full_name='data_room.Role.roleName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emailRegex', full_name='data_room.Role.emailRegex', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authenticationMethod', full_name='data_room.Role.authenticationMethod', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='data_room.Role.permissions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=459,
  serialized_end=610,
)


_PRIVACYSETTINGS = _descriptor.Descriptor(
  name='PrivacySettings',
  full_name='data_room.PrivacySettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='minAggregationGroupSize', full_name='data_room.PrivacySettings.minAggregationGroupSize', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=612,
  serialized_end=662,
)


_AUTHENTICATIONMETHOD = _descriptor.Descriptor(
  name='AuthenticationMethod',
  full_name='data_room.AuthenticationMethod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trustedPki', full_name='data_room.AuthenticationMethod.trustedPki', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mailPki', full_name='data_room.AuthenticationMethod.mailPki', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passwordSha256', full_name='data_room.AuthenticationMethod.passwordSha256', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=664,
  serialized_end=790,
)


_TRUSTEDPKI = _descriptor.Descriptor(
  name='TrustedPki',
  full_name='data_room.TrustedPki',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rootCertificate', full_name='data_room.TrustedPki.rootCertificate', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=792,
  serialized_end=829,
)


_MAILPKI = _descriptor.Descriptor(
  name='MailPki',
  full_name='data_room.MailPki',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rootCaStore', full_name='data_room.MailPki.rootCaStore', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=831,
  serialized_end=861,
)


_PERMISSION = _descriptor.Descriptor(
  name='Permission',
  full_name='data_room.Permission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submitQueryPermission', full_name='data_room.Permission.submitQueryPermission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tableCrudPermission', full_name='data_room.Permission.tableCrudPermission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataRoomRetrievalPermission', full_name='data_room.Permission.dataRoomRetrievalPermission', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auditLogRetrievalPermission', full_name='data_room.Permission.auditLogRetrievalPermission', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrieveDataRoomStatusPermission', full_name='data_room.Permission.retrieveDataRoomStatusPermission', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateDataRoomStatusPermission', full_name='data_room.Permission.updateDataRoomStatusPermission', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retrievePublishedDatasetsPermission', full_name='data_room.Permission.retrievePublishedDatasetsPermission', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='permission', full_name='data_room.Permission.permission',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=864,
  serialized_end=1447,
)


_SUBMITQUERYPERMISSION = _descriptor.Descriptor(
  name='SubmitQueryPermission',
  full_name='data_room.SubmitQueryPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queryName', full_name='data_room.SubmitQueryPermission.queryName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1449,
  serialized_end=1491,
)


_TABLECRUDPERMISSION = _descriptor.Descriptor(
  name='TableCrudPermission',
  full_name='data_room.TableCrudPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tableName', full_name='data_room.TableCrudPermission.tableName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1493,
  serialized_end=1533,
)


_DATAROOMRETRIEVALPERMISSION = _descriptor.Descriptor(
  name='DataroomRetrievalPermission',
  full_name='data_room.DataroomRetrievalPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1535,
  serialized_end=1564,
)


_AUDITLOGRETRIEVALPERMISSION = _descriptor.Descriptor(
  name='AuditLogRetrievalPermission',
  full_name='data_room.AuditLogRetrievalPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1566,
  serialized_end=1595,
)


_RETRIEVEDATAROOMSTATUSPERMISSION = _descriptor.Descriptor(
  name='RetrieveDataRoomStatusPermission',
  full_name='data_room.RetrieveDataRoomStatusPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1597,
  serialized_end=1631,
)


_UPDATEDATAROOMSTATUSPERMISSION = _descriptor.Descriptor(
  name='UpdateDataRoomStatusPermission',
  full_name='data_room.UpdateDataRoomStatusPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1633,
  serialized_end=1665,
)


_RETRIEVEPUBLISHEDDATASETSPERMISSION = _descriptor.Descriptor(
  name='RetrievePublishedDatasetsPermission',
  full_name='data_room.RetrievePublishedDatasetsPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1667,
  serialized_end=1704,
)


_CONSTRAINT = _descriptor.Descriptor(
  name='Constraint',
  full_name='data_room.Constraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='data_room.Constraint.description', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sqlConstraint', full_name='data_room.Constraint.sqlConstraint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeConstraint', full_name='data_room.Constraint.timeConstraint', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasetConstraint', full_name='data_room.Constraint.datasetConstraint', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='constraint', full_name='data_room.Constraint.constraint',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1707,
  serialized_end=1917,
)


_SQLCONSTRAINT = _descriptor.Descriptor(
  name='SqlConstraint',
  full_name='data_room.SqlConstraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statement', full_name='data_room.SqlConstraint.statement', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1919,
  serialized_end=1953,
)


_TIMECONSTRAINT = _descriptor.Descriptor(
  name='TimeConstraint',
  full_name='data_room.TimeConstraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='data_room.TimeConstraint.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='before', full_name='data_room.TimeConstraint.before', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1955,
  serialized_end=2006,
)


_DATASETCONSTRAINT = _descriptor.Descriptor(
  name='DatasetConstraint',
  full_name='data_room.DatasetConstraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='data_room.DatasetConstraint.table', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submissions', full_name='data_room.DatasetConstraint.submissions', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2008,
  serialized_end=2063,
)

_DATAROOM.fields_by_name['tables'].message_type = _TABLE
_DATAROOM.fields_by_name['queries'].message_type = _QUERY
_DATAROOM.fields_by_name['roles'].message_type = _ROLE
_TABLE.fields_by_name['submissionConstraints'].message_type = _TIMECONSTRAINT
_QUERY.fields_by_name['constraints'].message_type = _CONSTRAINT
_QUERY.fields_by_name['privacySettings'].message_type = _PRIVACYSETTINGS
_ROLE.fields_by_name['authenticationMethod'].message_type = _AUTHENTICATIONMETHOD
_ROLE.fields_by_name['permissions'].message_type = _PERMISSION
_AUTHENTICATIONMETHOD.fields_by_name['trustedPki'].message_type = _TRUSTEDPKI
_AUTHENTICATIONMETHOD.fields_by_name['mailPki'].message_type = _MAILPKI
_PERMISSION.fields_by_name['submitQueryPermission'].message_type = _SUBMITQUERYPERMISSION
_PERMISSION.fields_by_name['tableCrudPermission'].message_type = _TABLECRUDPERMISSION
_PERMISSION.fields_by_name['dataRoomRetrievalPermission'].message_type = _DATAROOMRETRIEVALPERMISSION
_PERMISSION.fields_by_name['auditLogRetrievalPermission'].message_type = _AUDITLOGRETRIEVALPERMISSION
_PERMISSION.fields_by_name['retrieveDataRoomStatusPermission'].message_type = _RETRIEVEDATAROOMSTATUSPERMISSION
_PERMISSION.fields_by_name['updateDataRoomStatusPermission'].message_type = _UPDATEDATAROOMSTATUSPERMISSION
_PERMISSION.fields_by_name['retrievePublishedDatasetsPermission'].message_type = _RETRIEVEPUBLISHEDDATASETSPERMISSION
_PERMISSION.oneofs_by_name['permission'].fields.append(
  _PERMISSION.fields_by_name['submitQueryPermission'])
_PERMISSION.fields_by_name['submitQueryPermission'].containing_oneof = _PERMISSION.oneofs_by_name['permission']
_PERMISSION.oneofs_by_name['permission'].fields.append(
  _PERMISSION.fields_by_name['tableCrudPermission'])
_PERMISSION.fields_by_name['tableCrudPermission'].containing_oneof = _PERMISSION.oneofs_by_name['permission']
_PERMISSION.oneofs_by_name['permission'].fields.append(
  _PERMISSION.fields_by_name['dataRoomRetrievalPermission'])
_PERMISSION.fields_by_name['dataRoomRetrievalPermission'].containing_oneof = _PERMISSION.oneofs_by_name['permission']
_PERMISSION.oneofs_by_name['permission'].fields.append(
  _PERMISSION.fields_by_name['auditLogRetrievalPermission'])
_PERMISSION.fields_by_name['auditLogRetrievalPermission'].containing_oneof = _PERMISSION.oneofs_by_name['permission']
_PERMISSION.oneofs_by_name['permission'].fields.append(
  _PERMISSION.fields_by_name['retrieveDataRoomStatusPermission'])
_PERMISSION.fields_by_name['retrieveDataRoomStatusPermission'].containing_oneof = _PERMISSION.oneofs_by_name['permission']
_PERMISSION.oneofs_by_name['permission'].fields.append(
  _PERMISSION.fields_by_name['updateDataRoomStatusPermission'])
_PERMISSION.fields_by_name['updateDataRoomStatusPermission'].containing_oneof = _PERMISSION.oneofs_by_name['permission']
_PERMISSION.oneofs_by_name['permission'].fields.append(
  _PERMISSION.fields_by_name['retrievePublishedDatasetsPermission'])
_PERMISSION.fields_by_name['retrievePublishedDatasetsPermission'].containing_oneof = _PERMISSION.oneofs_by_name['permission']
_CONSTRAINT.fields_by_name['sqlConstraint'].message_type = _SQLCONSTRAINT
_CONSTRAINT.fields_by_name['timeConstraint'].message_type = _TIMECONSTRAINT
_CONSTRAINT.fields_by_name['datasetConstraint'].message_type = _DATASETCONSTRAINT
_CONSTRAINT.oneofs_by_name['constraint'].fields.append(
  _CONSTRAINT.fields_by_name['sqlConstraint'])
_CONSTRAINT.fields_by_name['sqlConstraint'].containing_oneof = _CONSTRAINT.oneofs_by_name['constraint']
_CONSTRAINT.oneofs_by_name['constraint'].fields.append(
  _CONSTRAINT.fields_by_name['timeConstraint'])
_CONSTRAINT.fields_by_name['timeConstraint'].containing_oneof = _CONSTRAINT.oneofs_by_name['constraint']
_CONSTRAINT.oneofs_by_name['constraint'].fields.append(
  _CONSTRAINT.fields_by_name['datasetConstraint'])
_CONSTRAINT.fields_by_name['datasetConstraint'].containing_oneof = _CONSTRAINT.oneofs_by_name['constraint']
DESCRIPTOR.message_types_by_name['DataRoom'] = _DATAROOM
DESCRIPTOR.message_types_by_name['Table'] = _TABLE
DESCRIPTOR.message_types_by_name['Query'] = _QUERY
DESCRIPTOR.message_types_by_name['Role'] = _ROLE
DESCRIPTOR.message_types_by_name['PrivacySettings'] = _PRIVACYSETTINGS
DESCRIPTOR.message_types_by_name['AuthenticationMethod'] = _AUTHENTICATIONMETHOD
DESCRIPTOR.message_types_by_name['TrustedPki'] = _TRUSTEDPKI
DESCRIPTOR.message_types_by_name['MailPki'] = _MAILPKI
DESCRIPTOR.message_types_by_name['Permission'] = _PERMISSION
DESCRIPTOR.message_types_by_name['SubmitQueryPermission'] = _SUBMITQUERYPERMISSION
DESCRIPTOR.message_types_by_name['TableCrudPermission'] = _TABLECRUDPERMISSION
DESCRIPTOR.message_types_by_name['DataroomRetrievalPermission'] = _DATAROOMRETRIEVALPERMISSION
DESCRIPTOR.message_types_by_name['AuditLogRetrievalPermission'] = _AUDITLOGRETRIEVALPERMISSION
DESCRIPTOR.message_types_by_name['RetrieveDataRoomStatusPermission'] = _RETRIEVEDATAROOMSTATUSPERMISSION
DESCRIPTOR.message_types_by_name['UpdateDataRoomStatusPermission'] = _UPDATEDATAROOMSTATUSPERMISSION
DESCRIPTOR.message_types_by_name['RetrievePublishedDatasetsPermission'] = _RETRIEVEPUBLISHEDDATASETSPERMISSION
DESCRIPTOR.message_types_by_name['Constraint'] = _CONSTRAINT
DESCRIPTOR.message_types_by_name['SqlConstraint'] = _SQLCONSTRAINT
DESCRIPTOR.message_types_by_name['TimeConstraint'] = _TIMECONSTRAINT
DESCRIPTOR.message_types_by_name['DatasetConstraint'] = _DATASETCONSTRAINT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataRoom = _reflection.GeneratedProtocolMessageType('DataRoom', (_message.Message,), {
  'DESCRIPTOR' : _DATAROOM,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.DataRoom)
  })
_sym_db.RegisterMessage(DataRoom)

Table = _reflection.GeneratedProtocolMessageType('Table', (_message.Message,), {
  'DESCRIPTOR' : _TABLE,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.Table)
  })
_sym_db.RegisterMessage(Table)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.Query)
  })
_sym_db.RegisterMessage(Query)

Role = _reflection.GeneratedProtocolMessageType('Role', (_message.Message,), {
  'DESCRIPTOR' : _ROLE,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.Role)
  })
_sym_db.RegisterMessage(Role)

PrivacySettings = _reflection.GeneratedProtocolMessageType('PrivacySettings', (_message.Message,), {
  'DESCRIPTOR' : _PRIVACYSETTINGS,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.PrivacySettings)
  })
_sym_db.RegisterMessage(PrivacySettings)

AuthenticationMethod = _reflection.GeneratedProtocolMessageType('AuthenticationMethod', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATIONMETHOD,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.AuthenticationMethod)
  })
_sym_db.RegisterMessage(AuthenticationMethod)

TrustedPki = _reflection.GeneratedProtocolMessageType('TrustedPki', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTEDPKI,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.TrustedPki)
  })
_sym_db.RegisterMessage(TrustedPki)

MailPki = _reflection.GeneratedProtocolMessageType('MailPki', (_message.Message,), {
  'DESCRIPTOR' : _MAILPKI,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.MailPki)
  })
_sym_db.RegisterMessage(MailPki)

Permission = _reflection.GeneratedProtocolMessageType('Permission', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.Permission)
  })
_sym_db.RegisterMessage(Permission)

SubmitQueryPermission = _reflection.GeneratedProtocolMessageType('SubmitQueryPermission', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITQUERYPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.SubmitQueryPermission)
  })
_sym_db.RegisterMessage(SubmitQueryPermission)

TableCrudPermission = _reflection.GeneratedProtocolMessageType('TableCrudPermission', (_message.Message,), {
  'DESCRIPTOR' : _TABLECRUDPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.TableCrudPermission)
  })
_sym_db.RegisterMessage(TableCrudPermission)

DataroomRetrievalPermission = _reflection.GeneratedProtocolMessageType('DataroomRetrievalPermission', (_message.Message,), {
  'DESCRIPTOR' : _DATAROOMRETRIEVALPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.DataroomRetrievalPermission)
  })
_sym_db.RegisterMessage(DataroomRetrievalPermission)

AuditLogRetrievalPermission = _reflection.GeneratedProtocolMessageType('AuditLogRetrievalPermission', (_message.Message,), {
  'DESCRIPTOR' : _AUDITLOGRETRIEVALPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.AuditLogRetrievalPermission)
  })
_sym_db.RegisterMessage(AuditLogRetrievalPermission)

RetrieveDataRoomStatusPermission = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomStatusPermission', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMSTATUSPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.RetrieveDataRoomStatusPermission)
  })
_sym_db.RegisterMessage(RetrieveDataRoomStatusPermission)

UpdateDataRoomStatusPermission = _reflection.GeneratedProtocolMessageType('UpdateDataRoomStatusPermission', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAROOMSTATUSPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.UpdateDataRoomStatusPermission)
  })
_sym_db.RegisterMessage(UpdateDataRoomStatusPermission)

RetrievePublishedDatasetsPermission = _reflection.GeneratedProtocolMessageType('RetrievePublishedDatasetsPermission', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEPUBLISHEDDATASETSPERMISSION,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.RetrievePublishedDatasetsPermission)
  })
_sym_db.RegisterMessage(RetrievePublishedDatasetsPermission)

Constraint = _reflection.GeneratedProtocolMessageType('Constraint', (_message.Message,), {
  'DESCRIPTOR' : _CONSTRAINT,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.Constraint)
  })
_sym_db.RegisterMessage(Constraint)

SqlConstraint = _reflection.GeneratedProtocolMessageType('SqlConstraint', (_message.Message,), {
  'DESCRIPTOR' : _SQLCONSTRAINT,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.SqlConstraint)
  })
_sym_db.RegisterMessage(SqlConstraint)

TimeConstraint = _reflection.GeneratedProtocolMessageType('TimeConstraint', (_message.Message,), {
  'DESCRIPTOR' : _TIMECONSTRAINT,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.TimeConstraint)
  })
_sym_db.RegisterMessage(TimeConstraint)

DatasetConstraint = _reflection.GeneratedProtocolMessageType('DatasetConstraint', (_message.Message,), {
  'DESCRIPTOR' : _DATASETCONSTRAINT,
  '__module__' : 'data_room_pb2'
  # @@protoc_insertion_point(class_scope:data_room.DatasetConstraint)
  })
_sym_db.RegisterMessage(DatasetConstraint)


# @@protoc_insertion_point(module_scope)



import json
import chily
import argon2
import os
from collections.abc import Iterator
from google.protobuf.message import Message
from hashlib import sha256
from io import TextIOBase
from sqloxide import parse_sql # type: ignore
from typing import List, Tuple, Any, Union, Optional
from .proto.delta_enclave_api_pb2 import EncryptionHeader, VersionHeader, ChunkHeader
from .proto.length_delimited import serialize_length_delimited
from .proto.csv_table_format_pb2 import CsvTableFormat
from .proto.column_type_pb2 import ColumnType, PrimitiveType
from .proto.waterfront_pb2 import NamedColumn, TableSchema

__all__ = ["Key", "Schema"]

MAX_CHUNK_SIZE = 8 * 1024 * 1024
CHARSET = "utf-8"
KEY_LEN = 32
SALT_LEN = 16

class Key():
    """
    This class wraps the key material and identifier that is used to encrypt the
    datasets that are uploaded to the decentriq platform
    """
    def __init__(self, material: Optional[bytes] = None, salt: Optional[bytes] = None):
        """
        Returns a new `Key` instance, can optional specify the raw key material
        and salt to be used
        """
        if material == None:
            key_bytes = os.urandom(KEY_LEN)
        else:
            if len(material) != KEY_LEN:
                raise Exception("Invalid key length, must be 32 bytes")
            key_bytes = material

        if salt == None:
            salt_bytes = os.urandom(SALT_LEN)
        else:
            if len(salt) != SALT_LEN:
                raise Exception("Invalid salt length, must be 16 bytes")
            salt_bytes = salt

        self.id: bytes = argon2.low_level.hash_secret_raw(
                secret=key_bytes,
                salt=salt_bytes,
                time_cost=2,
                memory_cost=15360,
                parallelism=1,
                hash_len=32,
                type=argon2.low_level.Type.ID
        )
        self.material: bytes = key_bytes
        self.salt: bytes = salt_bytes

def sql_data_type_to_column_type(column_type: Union[str, dict], options) -> ColumnType:
    type = ColumnType()
    is_not_null = False
    for option in options:
        option_value = option["option"]
        if option_value == "NotNull":
            is_not_null = True
        else:
            raise Exception(f"Column option {option_value} not supported")

    type.nullable = not is_not_null

    if isinstance(column_type, str):
        if column_type == "Text":
            type.primitiveType =  PrimitiveType.STRING
        elif column_type == "Real" or column_type == "Double":
            type.primitiveType = PrimitiveType.FLOAT64 # type: ignore
        elif column_type == "SmallInt" or column_type == "Int" or column_type == "BigInt":
            type.primitiveType = PrimitiveType.INT64
    elif isinstance(column_type, dict):
        if "Char" in column_type or "Varchar" in column_type:
            type.primitiveType =  PrimitiveType.STRING
        elif "Float" in column_type:
            type.primitiveType = PrimitiveType.FLOAT64
    else:
        raise Exception(f"Unsupported data type {column_type}")

    return type


class Schema():
    """
    This class encodes the schema that describes the structure of a dataset
    """
    def __init__(self, create_table_statement: str):
        statements = parse_sql(create_table_statement, dialect="generic")
        if len(statements) == 0:
            raise Exception("No CREATE TABLE statements found")
        if len(statements) > 1:
            raise Exception("Single CREATE TABLE statement expected")
        statement = statements[0]
        if "CreateTable" in statement:
            create_table = statement["CreateTable"]
            table_names = create_table["name"]
            if len(table_names) != 1:
                raise Exception("Table name must be a single SQL identifier")
            table_name = table_names[0]["value"]
            used_column_names = set()
            named_columns: List[NamedColumn] = list()
            for column in create_table["columns"]:
                column_name = column["name"]["value"]
                if column_name in used_column_names:
                    raise Exception(f"Multiple definitions of column {column.name.value}")
                named_column = NamedColumn(
                        name=column_name,
                        columnType=sql_data_type_to_column_type(column["data_type"], column["options"])
                )
                named_columns.append(named_column)
            self.proto_schema: TableSchema = TableSchema(
                    namedColumns=named_columns
            )
            self.table_name: str = table_name
        else:
            raise Exception("CREATE TABLE statement expected");


def create_csv_chunk_header(extra_entropy: bytes) -> bytes:
    chunk_header = ChunkHeader()
    chunk_header.extraEntropy = extra_entropy
    chunk_header.formatIdentifier = "CsvTable"

    chunk_header_bytes = serialize_length_delimited(chunk_header)
    return chunk_header_bytes


def create_version_header() -> bytes:
    version_header = VersionHeader()
    version_header.version = 0
    return serialize_length_delimited(version_header)


def create_json_chunk_header(extra_entropy: bytes) -> bytes:
    chunk_header = ChunkHeader()
    chunk_header.extraEntropy = extra_entropy
    chunk_header.formatIdentifier = "JsonObject"
    chunk_header_bytes = serialize_length_delimited(chunk_header)

    return chunk_header_bytes


def create_protobuf_chunk_header(extra_entropy: bytes) -> bytes:
    chunk_header = ChunkHeader()
    chunk_header.extraEntropy = extra_entropy
    chunk_header.formatIdentifier = "ProtobufObject"
    chunk_header_bytes = serialize_length_delimited(chunk_header)

    return chunk_header_bytes


# Returns (integrity hash, encrypted blob)
def create_encrypted_json_object_chunk(
        key_id: bytes,
        key: bytes,
        extra_entropy: bytes,
        object: Any
) -> Tuple[bytes, bytes]:
    chunk_bytes = []

    version_header = create_version_header()
    chunk_bytes.append(version_header)

    chunk_header = create_json_chunk_header(extra_entropy)
    chunk_bytes.append(chunk_header)

    object_json = json.dumps(object).encode("utf-8")
    chunk_bytes.append(object_json)

    chunk = b''.join(chunk_bytes)
    chunk_hasher = sha256()
    chunk_hasher.update(chunk)
    chunk_hash = chunk_hasher.digest()

    cipher = StorageCipher(key, key_id)
    encrypted_chunk = cipher.encrypt(chunk)

    return chunk_hash, encrypted_chunk


# Returns (integrity hash, encrypted blob)
def create_encrypted_protobuf_object_chunk(
        key_id: bytes,
        key: bytes,
        extra_entropy: bytes,
        object: Message
) -> Tuple[bytes, bytes]:
    chunk_bytes = []

    version_header = create_version_header()
    chunk_bytes.append(version_header)

    chunk_header = create_protobuf_chunk_header(extra_entropy)
    chunk_bytes.append(chunk_header)

    object_protobuf = serialize_length_delimited(object)
    chunk_bytes.append(object_protobuf)

    chunk = b''.join(chunk_bytes)
    chunk_hasher = sha256()
    chunk_hasher.update(chunk)
    chunk_hash = chunk_hasher.digest()

    cipher = StorageCipher(key, key_id)
    encrypted_chunk = cipher.encrypt(chunk)

    return chunk_hash, encrypted_chunk


class CsvChunker(Iterator):
    def __init__(self, input_stream: TextIOBase, csv_column_types: List[int], chunk_size: int):
        self.chunk_size = chunk_size
        self.input_stream = input_stream
        self.csv_column_types = csv_column_types
        self.beginning_stream_offset = input_stream.tell()

    def reset(self):
        self.input_stream.seek(self.beginning_stream_offset)

    # returns (hash, chunk)
    def __next__(self) -> Tuple[bytes, bytes]:
        version_header_bytes = create_version_header()
        chunk_header_bytes = create_csv_chunk_header(os.urandom(16))

        csv_table_format = CsvTableFormat()
        csv_table_format.columnTypes.extend(self.csv_column_types)
        csv_table_format_bytes = serialize_length_delimited(csv_table_format)

        # Does not account for header size
        current_chunk_size = 0
        starting_offset = self.input_stream.tell()
        chunk_bytes = [version_header_bytes, chunk_header_bytes, csv_table_format_bytes]

        line = self.input_stream.readline()
        while line:
            line_bytes = line.encode(CHARSET)
            current_chunk_size = self.input_stream.tell() - starting_offset
            chunk_bytes.append(line_bytes)
            if current_chunk_size > self.chunk_size:
                break
            line = self.input_stream.readline()
        else:
            if current_chunk_size == 0:
                raise StopIteration

        chunk = b''.join(chunk_bytes)
        chunk_hasher = sha256()
        chunk_hasher.update(chunk)
        chunk_hash = chunk_hasher.digest()
        return chunk_hash, chunk


class StorageCipher:
    def __init__(self, symmetric_key: bytes, key_id: bytes):
        self.enc_key = symmetric_key
        self.enc_key_id = key_id
        self.cipher: chily.Cipher = chily.Cipher.from_symmetric(self.enc_key)

    def encrypt(self, data: bytes) -> bytes:
        nonce = chily.Nonce.from_random()
        encrypted_data = self.cipher.encrypt(data, nonce)

        encryption_header = EncryptionHeader()
        encryption_header.chilyKey.keyId = self.enc_key_id
        encryption_header.chilyKey.encryptionNonce = bytes(nonce.bytes)

        serialized_encryption_header = serialize_length_delimited(encryption_header)
        encrypted_data_with_header = bytes(list(serialized_encryption_header) + encrypted_data)
        return encrypted_data_with_header



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

global___PrimitiveType = PrimitiveType
class _PrimitiveType(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PrimitiveType.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    INT64 = PrimitiveType.V(1)
    STRING = PrimitiveType.V(2)
    FLOAT64 = PrimitiveType.V(3)
class PrimitiveType(metaclass=_PrimitiveType):
    V = typing.NewType('V', builtins.int)
INT64 = PrimitiveType.V(1)
STRING = PrimitiveType.V(2)
FLOAT64 = PrimitiveType.V(3)

class ColumnType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRIMITIVETYPE_FIELD_NUMBER: builtins.int
    NULLABLE_FIELD_NUMBER: builtins.int
    primitiveType: global___PrimitiveType.V = ...
    nullable: builtins.bool = ...

    def __init__(self,
        *,
        primitiveType : typing.Optional[global___PrimitiveType.V] = ...,
        nullable : typing.Optional[builtins.bool] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"nullable",b"nullable",u"primitiveType",b"primitiveType"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"nullable",b"nullable",u"primitiveType",b"primitiveType"]) -> None: ...
global___ColumnType = ColumnType



"""
.. include:: ../docs/getting_started.md

## The proto definitions

### DataRoom
```proto
.. include:: ../proto/data_room.proto
```

---

"""
__docformat__ = "restructuredtext"
from .client import Client

__all__ = ["Client", "session", "authentication", "storage", "proto", "types"]



import json
import io
import queue
import os
from base64 import b64encode
from concurrent import futures
from typing import List, Dict
from .api import API, Endpoints
from .authentication import generate_csr, generate_key, Auth
from .config import (
        DECENTRIQ_CLIENT_ID, DECENTRIQ_HOST, DECENTRIQ_PORT, DECENTRIQ_USE_TLS
)
from .proto.waterfront_pb2 import (
    DatasetManifest,
)
from .session import Session, SessionOptions
from .storage import (
    Key, Schema,
    create_encrypted_json_object_chunk,
    create_encrypted_protobuf_object_chunk,
    CsvChunker,
    StorageCipher
)
from .types import (
        EnclaveIdentifier, EnclaveIdentifiersResponse, FinalizeUpload,
        UserCsrRequest, UserCsrResponse, CreateSessionRequest, SessionJsonResponse,
        FileDescription, UploadDescription, ChunkWrapper, DataRoomDescription, PartialFileDescription
)

class Client:
    """
    Implementation of the decentriq platform REST API

    This class provides a Python interface to all functionality provided by
    the decentriq platform <https://platform.decentriq.com>
    """

    def __init__(
            self,
            api_token: str,
            client_id: str = DECENTRIQ_CLIENT_ID,
            host: str = DECENTRIQ_HOST,
            port: int = DECENTRIQ_PORT,
            use_tls: bool = DECENTRIQ_USE_TLS,
    ):
        """
        Create a new client instance. The API token can be obtained in the user
        panel of the decentriq platform <https://platform.decentriq.com/tokens>
        """
        self.api = API(
            api_token,
            client_id,
            host,
            port,
            use_tls
        )

    def get_ca_root_certificate(self) -> bytes:
        """
        Returns the decentriq root certificate used by the decentriq identity provider
        """
        url = Endpoints.SYSTEM_CERTIFICATE_AUTHORITY
        response = self.api.get(url).json()
        return response["rootCertificate"].encode("utf-8")

    def get_enclave_identifiers(self) -> List[EnclaveIdentifier]:
        """
        Returns the list of the currently deployed enclave services for which
        we can create a `decentriq_platform.session.Session` using `create_session`
        """
        url = Endpoints.SYSTEM_ENCLAVE_IDENTIFIERS
        response: EnclaveIdentifiersResponse = self.api.get(url).json()
        return response["enclaveIdentifiers"]

    def create_auth(self, email: str, access_token: str = None) -> Auth:
        """
        Creates a `decentriq_platform.authentication.Auth` object which can be
        attached to a `decentriq_platform.session.Session`
        """
        keypair = generate_key()
        csr = generate_csr(email, keypair)
        url = Endpoints.USER_CERTIFICATE.replace(":userId", email)
        csr_req = UserCsrRequest(csrPem=csr.decode("utf-8"))
        resp: UserCsrResponse = self.api.post(url, req_body=json.dumps(csr_req)).json()
        cert_chain_pem = resp["certChainPem"].encode("utf-8")
        auth = Auth(cert_chain_pem, keypair, email, access_token)
        return auth

    def create_session(
            self,
            enclave_identifier: EnclaveIdentifier,
            auth: Dict[str, Auth],
            options: SessionOptions
    ) -> Session:
        """
        Creates a new `decentriq_platform.session.Session` instance to communicate
        with an enclave service with the specified identifier.

        `auth` is a Python dictionary of `role_identifier` `->` `decentriq_platform.authentication.Auth` objects.
        Enclave messages sent thorugh this session will be authenticated
        with the authentication object identifier specified during a call.
        """
        url = Endpoints.SESSIONS
        req_body = CreateSessionRequest(enclaveIdentifier=enclave_identifier["enclaveIdentifier"])
        response: SessionJsonResponse = self.api.post(
                url,
                json.dumps(req_body),
                {"Content-type": "application/json"}
        ).json()
        session = Session(
                self,
                response["sessionId"],
                response["enclaveIdentifier"],
                auth,
                options
        )
        return session


    def upload_dataset(
            self,
            email: str,
            name: str,
            csv_input_stream: io.TextIOBase,
            schema: Schema,
            key: Key,
            chunk_size: int = 8 * 1024 ** 2,
            parallel_uploads: int = 8
    ) -> bytes:
        """
        Uploads `csv_input_stream` as a dataset usable by enclaves and returns the
        corresponding manifest hash

        **Parameters**:
        - `email`: owner of the file
        - `name`: name of the file
        - `csv_input_stream`: file content
        - `schema`: schema of the file
        - `key`: key used to encrypt the file
        """
        uploader = ThreadPoolExecutorWithQueueSizeLimit(
                max_workers=parallel_uploads, maxsize=parallel_uploads * 2)
        column_types = [named_column.columnType for named_column in schema.proto_schema.namedColumns]

        # create and upload chunks
        chunker = CsvChunker(csv_input_stream, column_types, chunk_size=chunk_size)
        chunk_hashes = []
        chunk_uploads_futures = []
        upload_description = self._create_upload(email)
        for chunk_hash, chunk_data in chunker:
            chunk_uploads_futures.append(
                uploader.submit(
                    self._encrypt_and_upload_chunk,
                    chunk_hash,
                    chunk_data,
                    key.material,
                    key.id,
                    email,
                    upload_description["uploadId"]
                )
            )
            chunk_hashes.append(chunk_hash.hex())

        # create digest chunks list and upload
        digest_hash, digest_encrypted = \
            create_encrypted_json_object_chunk(key.id, key.material, os.urandom(16), chunk_hashes)
        chunk_uploads_futures.append(
            uploader.submit(
                self._upload_chunk,
                digest_hash,
                digest_encrypted,
                email,
                upload_description["uploadId"]
            )
        )
        # check chunks uploads were successful
        completed, pending = futures.wait(chunk_uploads_futures, None, futures.FIRST_EXCEPTION)
        if len(pending):
            # reraise exception
            for future in completed: future.result()
        uploader.shutdown(wait=False)

        # create manifest and upload
        manifest = DatasetManifest()
        manifest.digestHash = digest_hash
        manifest.schema.CopyFrom(schema.proto_schema)
        manifest_hash, manifest_encrypted = \
            create_encrypted_protobuf_object_chunk(key.id, key.material, os.urandom(16), manifest)
        self._finalize_upload(
            user_id=email,
            upload_id=upload_description["uploadId"],
            name=name,
            manifest_hash=manifest_hash,
            manifest_encrypted=manifest_encrypted,
            # HACK!!! We include the digest hash as a "chunk".
            # This is temporary to avoid changes in the backend logic.
            chunks=chunk_hashes + [digest_hash.hex()]
        )
        return manifest_hash

    def _encrypt_and_upload_chunk(
            self,
            chunk_hash: bytes,
            chunk_data: bytes,
            key: bytes,
            key_id: bytes,
            user_id: str,
            upload_id: str
    ):
        cipher = StorageCipher(key, key_id)
        chunk_data_encrypted = cipher.encrypt(chunk_data)
        self._upload_chunk(chunk_hash, chunk_data_encrypted, user_id, upload_id)

    def _create_upload(self, user_id: str) -> UploadDescription:
        url = Endpoints.USER_UPLOADS_COLLECTION.replace(":userId", user_id)
        response = self.api.post(url, {}, {"Content-type": "application/json"})
        upload_description: UploadDescription = response.json()
        return upload_description

    def _upload_chunk(
            self,
            chunk_hash: bytes,
            chunk_data_encrypted: bytes,
            user_id: str,
            upload_id: str
    ):
        url = Endpoints.USER_UPLOAD_CHUNKS \
            .replace(":userId", user_id) \
            .replace(":uploadId", upload_id)
        wrapped_chunk= ChunkWrapper(
            hash=chunk_hash.hex(),
            data=b64encode(chunk_data_encrypted).decode("ascii")
        )
        self.api.post(url, json.dumps(wrapped_chunk), {"Content-type": "application/json"})

    def _delete_user_upload(self, email: str, upload_id: str):
        url = Endpoints.USER_UPLOAD \
            .replace(":userId", email) \
            .replace(":uploadId", upload_id)
        self.api.delete(url)

    def _get_user_upload(self, email: str, upload_id: str) -> UploadDescription:
        url = Endpoints.USER_UPLOAD.replace(":userId", email).replace(":uploadId", upload_id)
        response = self.api.get(url)
        return response.json()

    def _get_user_uploads_collection(self, email: str) -> List[UploadDescription]:
        url = Endpoints.USER_UPLOADS_COLLECTION.replace(":userId", email)
        response = self.api.get(url)
        return response.json()

    def _finalize_upload(
            self,
            user_id: str,
            upload_id: str,
            name: str,
            manifest_hash: bytes,
            manifest_encrypted: bytes,
            chunks: List[str]
    ) -> FileDescription:
        url = Endpoints.USER_FILES_COLLECTION.replace(":userId", user_id)
        payload = FinalizeUpload(
            uploadId=upload_id,
            manifest=b64encode(manifest_encrypted).decode("ascii"),
            manifestHash=manifest_hash.hex(),
            name=name,
            chunks=chunks
        )
        file_description: FileDescription = self.api.post(
            url,
            json.dumps(payload),
            {"Content-type": "application/json"}
        ).json()
        return file_description

    def _add_dataroom_to_user_file(
            self,
            email: str,
            data_room_id: bytes,
            table_name: str,
            current_file: FileDescription
    ) -> FileDescription:
        url = Endpoints.USER_FILE \
            .replace(":userId", email) \
            .replace(":manifestHash", current_file["manifestHash"])
        new_data_room_ids = current_file["dataRoomIds"] + [DataRoomDescription(
            dataRoomId=data_room_id.hex(),
            tableName=table_name
        )]
        payload = PartialFileDescription(dataRoomIds=new_data_room_ids)
        file_description: FileDescription = self.api.patch(
            url,
            json.dumps(payload),
            {"Content-type": "application/json"}
        ).json()
        return file_description

    def _remove_dataroom_from_user_file(
            self,
            email: str,
            data_room_id: bytes,
            table_name: str,
            current_file: FileDescription
    ) -> FileDescription:
        url = Endpoints.USER_FILE \
            .replace(":userId", email) \
            .replace(":manifestHash", current_file["manifestHash"])
        new_data_room_ids = list(filter(
                lambda id: id["dataRoomId"] != data_room_id.hex() and id["tableName"] != table_name, current_file["dataRoomIds"]
        ))
        payload = PartialFileDescription(dataRoomIds=new_data_room_ids)
        file_description: FileDescription = self.api.patch(
            url,
            json.dumps(payload),
            {"Content-type": "application/json"}
        ).json()
        return file_description

    def delete_user_file(self, email: str, manifest_hash: bytes):
        """
        Deletes a user file from the decentriq platform
        """
        url = Endpoints.USER_FILE \
            .replace(":userId", email) \
            .replace(":manifestHash", manifest_hash.hex())
        self.api.delete(url)

    def get_user_file(self, email: str, manifest_hash: bytes) -> FileDescription:
        """
        Returns informations about a user file
        """
        url = Endpoints.USER_FILE \
            .replace(":userId", email) \
            .replace(":manifestHash", manifest_hash.hex())
        response = self.api.get(url)
        return response.json()

    def get_user_files_collection(self, email: str) -> List[FileDescription]:
        """
        Returns the list of files uploaded by a user
        """
        url = Endpoints.USER_FILES_COLLECTION.replace(":userId", email)
        response = self.api.get(url)
        return response.json()

class ThreadPoolExecutorWithQueueSizeLimit(futures.ThreadPoolExecutor):
    def __init__(self, maxsize=50, *args, **kwargs):
        super(ThreadPoolExecutorWithQueueSizeLimit, self).__init__(*args, **kwargs)
        self._work_queue = queue.Queue(maxsize=maxsize) # type: ignore



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['decentriq_platform', 'decentriq_platform.proto']

package_data = \
{'': ['*']}

install_requires = \
['argon2-cffi>=20.1.0,<21.0.0',
 'asn1crypto>=1.2.0,<2.0.0',
 'certvalidator>=0.11.1,<0.12.0',
 'chily>=0.5.3,<0.6.0',
 'cryptography>=3.4.6,<4.0.0',
 'protobuf>=3.15.0,<4.0.0',
 'requests>=2.25.0,<3.0.0',
 'sgx-ias-structs>=0.1.7,<0.2.0',
 'sqloxide>=0.1.11,<0.2.0',
 'typing-extensions>=3.7.4,<4.0.0']

setup_kwargs = {
    'name': 'decentriq-platform',
    'version': '0.7.0',
    'description': 'Python client library for the Decentriq platform',
    'long_description': '# decentriq-platform-client\n\nPython client library for the Decentriq platform.\n\n## Installation\n\nAfter cloning the repository you can install the library using pip:\n\n### Virtual environment(optional)\n\nBefore installing the library you may want to working inside a virtual environment:\n\n```\npython -m venv env\nsource env/bin/activate\n```\n\n### Pip\n\nTo install with pip just run:\n\n```\npip install .\n```\n\n## Usage:\n\nTo have an idea of how to use this library, you can check the demo in the `example`\n directory.\n\n## Testing\n\nTo start the testing process install `nox` with `pip install nox` and the run it\nin the project directory. *N.B. make sure you have an available avato-backend*\n\n**nox**\n```\nnox\n```\n',
    'author': 'decentriq',
    'author_email': 'opensource@decentriq.ch',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/decentriq/decentriq-platform',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DataRoom(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ID_FIELD_NUMBER: builtins.int
    TABLES_FIELD_NUMBER: builtins.int
    QUERIES_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    MRENCLAVE_FIELD_NUMBER: builtins.int
    SINGLEEXECUTIONMODE_FIELD_NUMBER: builtins.int
    id: typing.Text = ...
    mrenclave: typing.Text = ...
    singleExecutionMode: builtins.bool = ...

    @property
    def tables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Table]: ...

    @property
    def queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Query]: ...

    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Role]: ...

    def __init__(self,
        *,
        id : typing.Optional[typing.Text] = ...,
        tables : typing.Optional[typing.Iterable[global___Table]] = ...,
        queries : typing.Optional[typing.Iterable[global___Query]] = ...,
        roles : typing.Optional[typing.Iterable[global___Role]] = ...,
        mrenclave : typing.Optional[typing.Text] = ...,
        singleExecutionMode : typing.Optional[builtins.bool] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"id",b"id",u"mrenclave",b"mrenclave",u"singleExecutionMode",b"singleExecutionMode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"id",b"id",u"mrenclave",b"mrenclave",u"queries",b"queries",u"roles",b"roles",u"singleExecutionMode",b"singleExecutionMode",u"tables",b"tables"]) -> None: ...
global___DataRoom = DataRoom

class Table(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SQLCREATETABLESTATEMENT_FIELD_NUMBER: builtins.int
    SUBMISSIONCONSTRAINTS_FIELD_NUMBER: builtins.int
    sqlCreateTableStatement: typing.Text = ...

    @property
    def submissionConstraints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TimeConstraint]: ...

    def __init__(self,
        *,
        sqlCreateTableStatement : typing.Optional[typing.Text] = ...,
        submissionConstraints : typing.Optional[typing.Iterable[global___TimeConstraint]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"sqlCreateTableStatement",b"sqlCreateTableStatement"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"sqlCreateTableStatement",b"sqlCreateTableStatement",u"submissionConstraints",b"submissionConstraints"]) -> None: ...
global___Table = Table

class Query(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    QUERYNAME_FIELD_NUMBER: builtins.int
    SQLSELECTSTATEMENT_FIELD_NUMBER: builtins.int
    CONSTRAINTS_FIELD_NUMBER: builtins.int
    PRIVACYSETTINGS_FIELD_NUMBER: builtins.int
    queryName: typing.Text = ...
    sqlSelectStatement: typing.Text = ...

    @property
    def constraints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Constraint]: ...

    @property
    def privacySettings(self) -> global___PrivacySettings: ...

    def __init__(self,
        *,
        queryName : typing.Optional[typing.Text] = ...,
        sqlSelectStatement : typing.Optional[typing.Text] = ...,
        constraints : typing.Optional[typing.Iterable[global___Constraint]] = ...,
        privacySettings : typing.Optional[global___PrivacySettings] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"privacySettings",b"privacySettings",u"queryName",b"queryName",u"sqlSelectStatement",b"sqlSelectStatement"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"constraints",b"constraints",u"privacySettings",b"privacySettings",u"queryName",b"queryName",u"sqlSelectStatement",b"sqlSelectStatement"]) -> None: ...
global___Query = Query

class Role(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ROLENAME_FIELD_NUMBER: builtins.int
    EMAILREGEX_FIELD_NUMBER: builtins.int
    AUTHENTICATIONMETHOD_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    roleName: typing.Text = ...
    emailRegex: typing.Text = ...

    @property
    def authenticationMethod(self) -> global___AuthenticationMethod: ...

    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]: ...

    def __init__(self,
        *,
        roleName : typing.Optional[typing.Text] = ...,
        emailRegex : typing.Optional[typing.Text] = ...,
        authenticationMethod : typing.Optional[global___AuthenticationMethod] = ...,
        permissions : typing.Optional[typing.Iterable[global___Permission]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"authenticationMethod",b"authenticationMethod",u"emailRegex",b"emailRegex",u"roleName",b"roleName"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"authenticationMethod",b"authenticationMethod",u"emailRegex",b"emailRegex",u"permissions",b"permissions",u"roleName",b"roleName"]) -> None: ...
global___Role = Role

class PrivacySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MINAGGREGATIONGROUPSIZE_FIELD_NUMBER: builtins.int
    minAggregationGroupSize: builtins.int = ...

    def __init__(self,
        *,
        minAggregationGroupSize : typing.Optional[builtins.int] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"minAggregationGroupSize",b"minAggregationGroupSize"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"minAggregationGroupSize",b"minAggregationGroupSize"]) -> None: ...
global___PrivacySettings = PrivacySettings

class AuthenticationMethod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TRUSTEDPKI_FIELD_NUMBER: builtins.int
    MAILPKI_FIELD_NUMBER: builtins.int
    PASSWORDSHA256_FIELD_NUMBER: builtins.int
    passwordSha256: typing.Text = ...

    @property
    def trustedPki(self) -> global___TrustedPki: ...

    @property
    def mailPki(self) -> global___MailPki: ...

    def __init__(self,
        *,
        trustedPki : typing.Optional[global___TrustedPki] = ...,
        mailPki : typing.Optional[global___MailPki] = ...,
        passwordSha256 : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"mailPki",b"mailPki",u"passwordSha256",b"passwordSha256",u"trustedPki",b"trustedPki"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"mailPki",b"mailPki",u"passwordSha256",b"passwordSha256",u"trustedPki",b"trustedPki"]) -> None: ...
global___AuthenticationMethod = AuthenticationMethod

class TrustedPki(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ROOTCERTIFICATE_FIELD_NUMBER: builtins.int
    rootCertificate: builtins.bytes = ...

    def __init__(self,
        *,
        rootCertificate : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"rootCertificate",b"rootCertificate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"rootCertificate",b"rootCertificate"]) -> None: ...
global___TrustedPki = TrustedPki

class MailPki(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ROOTCASTORE_FIELD_NUMBER: builtins.int
    rootCaStore: builtins.bytes = ...

    def __init__(self,
        *,
        rootCaStore : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"rootCaStore",b"rootCaStore"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"rootCaStore",b"rootCaStore"]) -> None: ...
global___MailPki = MailPki

class Permission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SUBMITQUERYPERMISSION_FIELD_NUMBER: builtins.int
    TABLECRUDPERMISSION_FIELD_NUMBER: builtins.int
    DATAROOMRETRIEVALPERMISSION_FIELD_NUMBER: builtins.int
    AUDITLOGRETRIEVALPERMISSION_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMSTATUSPERMISSION_FIELD_NUMBER: builtins.int
    UPDATEDATAROOMSTATUSPERMISSION_FIELD_NUMBER: builtins.int
    RETRIEVEPUBLISHEDDATASETSPERMISSION_FIELD_NUMBER: builtins.int

    @property
    def submitQueryPermission(self) -> global___SubmitQueryPermission: ...

    @property
    def tableCrudPermission(self) -> global___TableCrudPermission: ...

    @property
    def dataRoomRetrievalPermission(self) -> global___DataroomRetrievalPermission: ...

    @property
    def auditLogRetrievalPermission(self) -> global___AuditLogRetrievalPermission: ...

    @property
    def retrieveDataRoomStatusPermission(self) -> global___RetrieveDataRoomStatusPermission: ...

    @property
    def updateDataRoomStatusPermission(self) -> global___UpdateDataRoomStatusPermission: ...

    @property
    def retrievePublishedDatasetsPermission(self) -> global___RetrievePublishedDatasetsPermission: ...

    def __init__(self,
        *,
        submitQueryPermission : typing.Optional[global___SubmitQueryPermission] = ...,
        tableCrudPermission : typing.Optional[global___TableCrudPermission] = ...,
        dataRoomRetrievalPermission : typing.Optional[global___DataroomRetrievalPermission] = ...,
        auditLogRetrievalPermission : typing.Optional[global___AuditLogRetrievalPermission] = ...,
        retrieveDataRoomStatusPermission : typing.Optional[global___RetrieveDataRoomStatusPermission] = ...,
        updateDataRoomStatusPermission : typing.Optional[global___UpdateDataRoomStatusPermission] = ...,
        retrievePublishedDatasetsPermission : typing.Optional[global___RetrievePublishedDatasetsPermission] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auditLogRetrievalPermission",b"auditLogRetrievalPermission",u"dataRoomRetrievalPermission",b"dataRoomRetrievalPermission",u"permission",b"permission",u"retrieveDataRoomStatusPermission",b"retrieveDataRoomStatusPermission",u"retrievePublishedDatasetsPermission",b"retrievePublishedDatasetsPermission",u"submitQueryPermission",b"submitQueryPermission",u"tableCrudPermission",b"tableCrudPermission",u"updateDataRoomStatusPermission",b"updateDataRoomStatusPermission"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auditLogRetrievalPermission",b"auditLogRetrievalPermission",u"dataRoomRetrievalPermission",b"dataRoomRetrievalPermission",u"permission",b"permission",u"retrieveDataRoomStatusPermission",b"retrieveDataRoomStatusPermission",u"retrievePublishedDatasetsPermission",b"retrievePublishedDatasetsPermission",u"submitQueryPermission",b"submitQueryPermission",u"tableCrudPermission",b"tableCrudPermission",u"updateDataRoomStatusPermission",b"updateDataRoomStatusPermission"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"permission",b"permission"]) -> typing_extensions.Literal["submitQueryPermission","tableCrudPermission","dataRoomRetrievalPermission","auditLogRetrievalPermission","retrieveDataRoomStatusPermission","updateDataRoomStatusPermission","retrievePublishedDatasetsPermission"]: ...
global___Permission = Permission

class SubmitQueryPermission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    QUERYNAME_FIELD_NUMBER: builtins.int
    queryName: typing.Text = ...

    def __init__(self,
        *,
        queryName : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"queryName",b"queryName"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"queryName",b"queryName"]) -> None: ...
global___SubmitQueryPermission = SubmitQueryPermission

class TableCrudPermission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TABLENAME_FIELD_NUMBER: builtins.int
    tableName: typing.Text = ...

    def __init__(self,
        *,
        tableName : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"tableName",b"tableName"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"tableName",b"tableName"]) -> None: ...
global___TableCrudPermission = TableCrudPermission

class DataroomRetrievalPermission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___DataroomRetrievalPermission = DataroomRetrievalPermission

class AuditLogRetrievalPermission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___AuditLogRetrievalPermission = AuditLogRetrievalPermission

class RetrieveDataRoomStatusPermission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___RetrieveDataRoomStatusPermission = RetrieveDataRoomStatusPermission

class UpdateDataRoomStatusPermission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___UpdateDataRoomStatusPermission = UpdateDataRoomStatusPermission

class RetrievePublishedDatasetsPermission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___RetrievePublishedDatasetsPermission = RetrievePublishedDatasetsPermission

class Constraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SQLCONSTRAINT_FIELD_NUMBER: builtins.int
    TIMECONSTRAINT_FIELD_NUMBER: builtins.int
    DATASETCONSTRAINT_FIELD_NUMBER: builtins.int
    description: typing.Text = ...

    @property
    def sqlConstraint(self) -> global___SqlConstraint: ...

    @property
    def timeConstraint(self) -> global___TimeConstraint: ...

    @property
    def datasetConstraint(self) -> global___DatasetConstraint: ...

    def __init__(self,
        *,
        description : typing.Optional[typing.Text] = ...,
        sqlConstraint : typing.Optional[global___SqlConstraint] = ...,
        timeConstraint : typing.Optional[global___TimeConstraint] = ...,
        datasetConstraint : typing.Optional[global___DatasetConstraint] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"constraint",b"constraint",u"datasetConstraint",b"datasetConstraint",u"description",b"description",u"sqlConstraint",b"sqlConstraint",u"timeConstraint",b"timeConstraint"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"constraint",b"constraint",u"datasetConstraint",b"datasetConstraint",u"description",b"description",u"sqlConstraint",b"sqlConstraint",u"timeConstraint",b"timeConstraint"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"constraint",b"constraint"]) -> typing_extensions.Literal["sqlConstraint","timeConstraint","datasetConstraint"]: ...
global___Constraint = Constraint

class SqlConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATEMENT_FIELD_NUMBER: builtins.int
    statement: typing.Text = ...

    def __init__(self,
        *,
        statement : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"statement",b"statement"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"statement",b"statement"]) -> None: ...
global___SqlConstraint = SqlConstraint

class TimeConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TIMESTAMP_FIELD_NUMBER: builtins.int
    BEFORE_FIELD_NUMBER: builtins.int
    timestamp: builtins.int = ...
    before: builtins.bool = ...

    def __init__(self,
        *,
        timestamp : typing.Optional[builtins.int] = ...,
        before : typing.Optional[builtins.bool] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"before",b"before",u"timestamp",b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"before",b"before",u"timestamp",b"timestamp"]) -> None: ...
global___TimeConstraint = TimeConstraint

class DatasetConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TABLE_FIELD_NUMBER: builtins.int
    SUBMISSIONS_FIELD_NUMBER: builtins.int
    table: typing.Text = ...
    submissions: builtins.int = ...

    def __init__(self,
        *,
        table : typing.Optional[typing.Text] = ...,
        submissions : typing.Optional[builtins.int] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"submissions",b"submissions",u"table",b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"submissions",b"submissions",u"table",b"table"]) -> None: ...
global___DatasetConstraint = DatasetConstraint



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: csv_table_format.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import column_type_pb2 as column__type__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='csv_table_format.proto',
  package='csv_table_format',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16\x63sv_table_format.proto\x12\x10\x63sv_table_format\x1a\x11\x63olumn_type.proto\">\n\x0e\x43svTableFormat\x12,\n\x0b\x63olumnTypes\x18\x01 \x03(\x0b\x32\x17.column_type.ColumnType'
  ,
  dependencies=[column__type__pb2.DESCRIPTOR,])




_CSVTABLEFORMAT = _descriptor.Descriptor(
  name='CsvTableFormat',
  full_name='csv_table_format.CsvTableFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='columnTypes', full_name='csv_table_format.CsvTableFormat.columnTypes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=125,
)

_CSVTABLEFORMAT.fields_by_name['columnTypes'].message_type = column__type__pb2._COLUMNTYPE
DESCRIPTOR.message_types_by_name['CsvTableFormat'] = _CSVTABLEFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CsvTableFormat = _reflection.GeneratedProtocolMessageType('CsvTableFormat', (_message.Message,), {
  'DESCRIPTOR' : _CSVTABLEFORMAT,
  '__module__' : 'csv_table_format_pb2'
  # @@protoc_insertion_point(class_scope:csv_table_format.CsvTableFormat)
  })
_sym_db.RegisterMessage(CsvTableFormat)


# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import column_type_pb2
import data_room_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

global___DataRoomStatus = DataRoomStatus
class _DataRoomStatus(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DataRoomStatus.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    Active = DataRoomStatus.V(1)
    Stopped = DataRoomStatus.V(2)
class DataRoomStatus(metaclass=_DataRoomStatus):
    V = typing.NewType('V', builtins.int)
Active = DataRoomStatus.V(1)
Stopped = DataRoomStatus.V(2)

class WaterfrontRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SQLQUERYREQUEST_FIELD_NUMBER: builtins.int
    CREATEDATAROOMREQUEST_FIELD_NUMBER: builtins.int
    PUBLISHDATASETTODATAROOMREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMREQUEST_FIELD_NUMBER: builtins.int
    VALIDATEDATASETREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEAUDITLOGREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMSTATUSREQUEST_FIELD_NUMBER: builtins.int
    UPDATEDATAROOMSTATUSREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEPUBLISHEDDATASETREQUEST_FIELD_NUMBER: builtins.int
    REMOVEPUBLISHEDDATASETREQUEST_FIELD_NUMBER: builtins.int
    JOBSTATUSREQUEST_FIELD_NUMBER: builtins.int
    GETRESULTSREQUEST_FIELD_NUMBER: builtins.int
    VALIDATEQUERIESREQUEST_FIELD_NUMBER: builtins.int

    @property
    def sqlQueryRequest(self) -> global___SqlQueryRequest: ...

    @property
    def createDataRoomRequest(self) -> global___CreateDataRoomRequest: ...

    @property
    def publishDatasetToDataRoomRequest(self) -> global___PublishDatasetToDataRoomRequest: ...

    @property
    def retrieveDataRoomRequest(self) -> global___RetrieveDataRoomRequest: ...

    @property
    def validateDatasetRequest(self) -> global___ValidateDatasetRequest: ...

    @property
    def retrieveAuditLogRequest(self) -> global___RetrieveAuditLogRequest: ...

    @property
    def retrieveDataRoomStatusRequest(self) -> global___RetrieveDataRoomStatusRequest: ...

    @property
    def updateDataRoomStatusRequest(self) -> global___UpdateDataRoomStatusRequest: ...

    @property
    def retrievePublishedDatasetRequest(self) -> global___RetrievePublishedDatasetRequest: ...

    @property
    def removePublishedDatasetRequest(self) -> global___RemovePublishedDatasetRequest: ...

    @property
    def jobStatusRequest(self) -> global___JobStatusRequest: ...

    @property
    def getResultsRequest(self) -> global___GetResultsRequest: ...

    @property
    def validateQueriesRequest(self) -> global___ValidateQueriesRequest: ...

    def __init__(self,
        *,
        sqlQueryRequest : typing.Optional[global___SqlQueryRequest] = ...,
        createDataRoomRequest : typing.Optional[global___CreateDataRoomRequest] = ...,
        publishDatasetToDataRoomRequest : typing.Optional[global___PublishDatasetToDataRoomRequest] = ...,
        retrieveDataRoomRequest : typing.Optional[global___RetrieveDataRoomRequest] = ...,
        validateDatasetRequest : typing.Optional[global___ValidateDatasetRequest] = ...,
        retrieveAuditLogRequest : typing.Optional[global___RetrieveAuditLogRequest] = ...,
        retrieveDataRoomStatusRequest : typing.Optional[global___RetrieveDataRoomStatusRequest] = ...,
        updateDataRoomStatusRequest : typing.Optional[global___UpdateDataRoomStatusRequest] = ...,
        retrievePublishedDatasetRequest : typing.Optional[global___RetrievePublishedDatasetRequest] = ...,
        removePublishedDatasetRequest : typing.Optional[global___RemovePublishedDatasetRequest] = ...,
        jobStatusRequest : typing.Optional[global___JobStatusRequest] = ...,
        getResultsRequest : typing.Optional[global___GetResultsRequest] = ...,
        validateQueriesRequest : typing.Optional[global___ValidateQueriesRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"createDataRoomRequest",b"createDataRoomRequest",u"getResultsRequest",b"getResultsRequest",u"jobStatusRequest",b"jobStatusRequest",u"publishDatasetToDataRoomRequest",b"publishDatasetToDataRoomRequest",u"removePublishedDatasetRequest",b"removePublishedDatasetRequest",u"retrieveAuditLogRequest",b"retrieveAuditLogRequest",u"retrieveDataRoomRequest",b"retrieveDataRoomRequest",u"retrieveDataRoomStatusRequest",b"retrieveDataRoomStatusRequest",u"retrievePublishedDatasetRequest",b"retrievePublishedDatasetRequest",u"sqlQueryRequest",b"sqlQueryRequest",u"updateDataRoomStatusRequest",b"updateDataRoomStatusRequest",u"validateDatasetRequest",b"validateDatasetRequest",u"validateQueriesRequest",b"validateQueriesRequest",u"waterfront_request",b"waterfront_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"createDataRoomRequest",b"createDataRoomRequest",u"getResultsRequest",b"getResultsRequest",u"jobStatusRequest",b"jobStatusRequest",u"publishDatasetToDataRoomRequest",b"publishDatasetToDataRoomRequest",u"removePublishedDatasetRequest",b"removePublishedDatasetRequest",u"retrieveAuditLogRequest",b"retrieveAuditLogRequest",u"retrieveDataRoomRequest",b"retrieveDataRoomRequest",u"retrieveDataRoomStatusRequest",b"retrieveDataRoomStatusRequest",u"retrievePublishedDatasetRequest",b"retrievePublishedDatasetRequest",u"sqlQueryRequest",b"sqlQueryRequest",u"updateDataRoomStatusRequest",b"updateDataRoomStatusRequest",u"validateDatasetRequest",b"validateDatasetRequest",u"validateQueriesRequest",b"validateQueriesRequest",u"waterfront_request",b"waterfront_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"waterfront_request",b"waterfront_request"]) -> typing_extensions.Literal["sqlQueryRequest","createDataRoomRequest","publishDatasetToDataRoomRequest","retrieveDataRoomRequest","validateDatasetRequest","retrieveAuditLogRequest","retrieveDataRoomStatusRequest","updateDataRoomStatusRequest","retrievePublishedDatasetRequest","removePublishedDatasetRequest","jobStatusRequest","getResultsRequest","validateQueriesRequest"]: ...
global___WaterfrontRequest = WaterfrontRequest

class WaterfrontResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FAILURE_FIELD_NUMBER: builtins.int
    SQLQUERYRESPONSE_FIELD_NUMBER: builtins.int
    CREATEDATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    PUBLISHDATASETTODATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    VALIDATEDATASETRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEAUDITLOGRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    UPDATEDATAROOMSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEPUBLISHEDDATASETRESPONSE_FIELD_NUMBER: builtins.int
    REMOVEPUBLISHEDDATASETRESPONSE_FIELD_NUMBER: builtins.int
    JOBSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    VALIDATEQUERIESRESPONSE_FIELD_NUMBER: builtins.int
    failure: typing.Text = ...

    @property
    def sqlQueryResponse(self) -> global___SqlQueryResponse: ...

    @property
    def createDataRoomResponse(self) -> global___CreateDataRoomResponse: ...

    @property
    def publishDatasetToDataRoomResponse(self) -> global___PublishDatasetToDataRoomResponse: ...

    @property
    def retrieveDataRoomResponse(self) -> global___RetrieveDataRoomResponse: ...

    @property
    def validateDatasetResponse(self) -> global___ValidateDatasetResponse: ...

    @property
    def retrieveAuditLogResponse(self) -> global___RetrieveAuditLogResponse: ...

    @property
    def retrieveDataRoomStatusResponse(self) -> global___RetrieveDataRoomStatusResponse: ...

    @property
    def updateDataRoomStatusResponse(self) -> global___UpdateDataRoomStatusResponse: ...

    @property
    def retrievePublishedDatasetResponse(self) -> global___RetrievePublishedDatasetResponse: ...

    @property
    def removePublishedDatasetResponse(self) -> global___RemovePublishedDatasetResponse: ...

    @property
    def jobStatusResponse(self) -> global___JobStatusResponse: ...

    @property
    def validateQueriesResponse(self) -> global___ValidateQueriesResponse: ...

    def __init__(self,
        *,
        failure : typing.Optional[typing.Text] = ...,
        sqlQueryResponse : typing.Optional[global___SqlQueryResponse] = ...,
        createDataRoomResponse : typing.Optional[global___CreateDataRoomResponse] = ...,
        publishDatasetToDataRoomResponse : typing.Optional[global___PublishDatasetToDataRoomResponse] = ...,
        retrieveDataRoomResponse : typing.Optional[global___RetrieveDataRoomResponse] = ...,
        validateDatasetResponse : typing.Optional[global___ValidateDatasetResponse] = ...,
        retrieveAuditLogResponse : typing.Optional[global___RetrieveAuditLogResponse] = ...,
        retrieveDataRoomStatusResponse : typing.Optional[global___RetrieveDataRoomStatusResponse] = ...,
        updateDataRoomStatusResponse : typing.Optional[global___UpdateDataRoomStatusResponse] = ...,
        retrievePublishedDatasetResponse : typing.Optional[global___RetrievePublishedDatasetResponse] = ...,
        removePublishedDatasetResponse : typing.Optional[global___RemovePublishedDatasetResponse] = ...,
        jobStatusResponse : typing.Optional[global___JobStatusResponse] = ...,
        validateQueriesResponse : typing.Optional[global___ValidateQueriesResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"createDataRoomResponse",b"createDataRoomResponse",u"failure",b"failure",u"jobStatusResponse",b"jobStatusResponse",u"publishDatasetToDataRoomResponse",b"publishDatasetToDataRoomResponse",u"removePublishedDatasetResponse",b"removePublishedDatasetResponse",u"retrieveAuditLogResponse",b"retrieveAuditLogResponse",u"retrieveDataRoomResponse",b"retrieveDataRoomResponse",u"retrieveDataRoomStatusResponse",b"retrieveDataRoomStatusResponse",u"retrievePublishedDatasetResponse",b"retrievePublishedDatasetResponse",u"sqlQueryResponse",b"sqlQueryResponse",u"updateDataRoomStatusResponse",b"updateDataRoomStatusResponse",u"validateDatasetResponse",b"validateDatasetResponse",u"validateQueriesResponse",b"validateQueriesResponse",u"waterfront_response",b"waterfront_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"createDataRoomResponse",b"createDataRoomResponse",u"failure",b"failure",u"jobStatusResponse",b"jobStatusResponse",u"publishDatasetToDataRoomResponse",b"publishDatasetToDataRoomResponse",u"removePublishedDatasetResponse",b"removePublishedDatasetResponse",u"retrieveAuditLogResponse",b"retrieveAuditLogResponse",u"retrieveDataRoomResponse",b"retrieveDataRoomResponse",u"retrieveDataRoomStatusResponse",b"retrieveDataRoomStatusResponse",u"retrievePublishedDatasetResponse",b"retrievePublishedDatasetResponse",u"sqlQueryResponse",b"sqlQueryResponse",u"updateDataRoomStatusResponse",b"updateDataRoomStatusResponse",u"validateDatasetResponse",b"validateDatasetResponse",u"validateQueriesResponse",b"validateQueriesResponse",u"waterfront_response",b"waterfront_response"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"waterfront_response",b"waterfront_response"]) -> typing_extensions.Literal["failure","sqlQueryResponse","createDataRoomResponse","publishDatasetToDataRoomResponse","retrieveDataRoomResponse","validateDatasetResponse","retrieveAuditLogResponse","retrieveDataRoomStatusResponse","updateDataRoomStatusResponse","retrievePublishedDatasetResponse","removePublishedDatasetResponse","jobStatusResponse","validateQueriesResponse"]: ...
global___WaterfrontResponse = WaterfrontResponse

class AuthenticationData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ROLE_FIELD_NUMBER: builtins.int
    PASSWORDSHA256_FIELD_NUMBER: builtins.int
    role: typing.Text = ...
    passwordSha256: typing.Text = ...

    def __init__(self,
        *,
        role : typing.Optional[typing.Text] = ...,
        passwordSha256 : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"passwordSha256",b"passwordSha256",u"role",b"role"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"passwordSha256",b"passwordSha256",u"role",b"role"]) -> None: ...
global___AuthenticationData = AuthenticationData

class CreateDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOM_FIELD_NUMBER: builtins.int

    @property
    def dataRoom(self) -> data_room_pb2.DataRoom: ...

    def __init__(self,
        *,
        dataRoom : typing.Optional[data_room_pb2.DataRoom] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> None: ...
global___CreateDataRoomRequest = CreateDataRoomRequest

class CreateDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    DATAROOMVALIDATIONERROR_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.bytes = ...

    @property
    def dataRoomValidationError(self) -> global___DataRoomValidationError: ...

    def __init__(self,
        *,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        dataRoomValidationError : typing.Optional[global___DataRoomValidationError] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"create_data_room_response",b"create_data_room_response",u"dataRoomHash",b"dataRoomHash",u"dataRoomValidationError",b"dataRoomValidationError"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"create_data_room_response",b"create_data_room_response",u"dataRoomHash",b"dataRoomHash",u"dataRoomValidationError",b"dataRoomValidationError"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"create_data_room_response",b"create_data_room_response"]) -> typing_extensions.Literal["dataRoomHash","dataRoomValidationError"]: ...
global___CreateDataRoomResponse = CreateDataRoomResponse

class DataRoomValidationError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MESSAGE_FIELD_NUMBER: builtins.int
    QUERYINDEX_FIELD_NUMBER: builtins.int
    COLUMNINDEX_FIELD_NUMBER: builtins.int
    TABLEINDEX_FIELD_NUMBER: builtins.int
    ROLEINDEX_FIELD_NUMBER: builtins.int
    PERMISSIONINDEX_FIELD_NUMBER: builtins.int
    CONSTRAINTINDEX_FIELD_NUMBER: builtins.int
    message: typing.Text = ...
    queryIndex: builtins.int = ...
    columnIndex: builtins.int = ...
    tableIndex: builtins.int = ...
    roleIndex: builtins.int = ...
    permissionIndex: builtins.int = ...
    constraintIndex: builtins.int = ...

    def __init__(self,
        *,
        message : typing.Optional[typing.Text] = ...,
        queryIndex : typing.Optional[builtins.int] = ...,
        columnIndex : typing.Optional[builtins.int] = ...,
        tableIndex : typing.Optional[builtins.int] = ...,
        roleIndex : typing.Optional[builtins.int] = ...,
        permissionIndex : typing.Optional[builtins.int] = ...,
        constraintIndex : typing.Optional[builtins.int] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"columnIndex",b"columnIndex",u"constraintIndex",b"constraintIndex",u"message",b"message",u"permissionIndex",b"permissionIndex",u"queryIndex",b"queryIndex",u"roleIndex",b"roleIndex",u"tableIndex",b"tableIndex"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"columnIndex",b"columnIndex",u"constraintIndex",b"constraintIndex",u"message",b"message",u"permissionIndex",b"permissionIndex",u"queryIndex",b"queryIndex",u"roleIndex",b"roleIndex",u"tableIndex",b"tableIndex"]) -> None: ...
global___DataRoomValidationError = DataRoomValidationError

class PublishDatasetToDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MANIFESTHASH_FIELD_NUMBER: builtins.int
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    DATAROOMTABLENAME_FIELD_NUMBER: builtins.int
    ENCRYPTIONKEY_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    manifestHash: builtins.bytes = ...
    dataRoomHash: builtins.bytes = ...
    dataRoomTableName: typing.Text = ...

    @property
    def encryptionKey(self) -> global___EncryptionKey: ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        manifestHash : typing.Optional[builtins.bytes] = ...,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        dataRoomTableName : typing.Optional[typing.Text] = ...,
        encryptionKey : typing.Optional[global___EncryptionKey] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"dataRoomTableName",b"dataRoomTableName",u"encryptionKey",b"encryptionKey",u"manifestHash",b"manifestHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"dataRoomTableName",b"dataRoomTableName",u"encryptionKey",b"encryptionKey",u"manifestHash",b"manifestHash"]) -> None: ...
global___PublishDatasetToDataRoomRequest = PublishDatasetToDataRoomRequest

class PublishDatasetToDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___PublishDatasetToDataRoomResponse = PublishDatasetToDataRoomResponse

class ValidateDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MANIFESTHASH_FIELD_NUMBER: builtins.int
    ENCRYPTIONKEY_FIELD_NUMBER: builtins.int
    manifestHash: builtins.bytes = ...

    @property
    def encryptionKey(self) -> global___EncryptionKey: ...

    def __init__(self,
        *,
        manifestHash : typing.Optional[builtins.bytes] = ...,
        encryptionKey : typing.Optional[global___EncryptionKey] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"encryptionKey",b"encryptionKey",u"manifestHash",b"manifestHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"encryptionKey",b"encryptionKey",u"manifestHash",b"manifestHash"]) -> None: ...
global___ValidateDatasetRequest = ValidateDatasetRequest

class ValidateDatasetFailure(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MESSAGE_FIELD_NUMBER: builtins.int
    ROW_FIELD_NUMBER: builtins.int
    message: typing.Text = ...
    row: builtins.int = ...

    def __init__(self,
        *,
        message : typing.Optional[typing.Text] = ...,
        row : typing.Optional[builtins.int] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"message",b"message",u"row",b"row"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"message",b"message",u"row",b"row"]) -> None: ...
global___ValidateDatasetFailure = ValidateDatasetFailure

class ValidateDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FAILURE_FIELD_NUMBER: builtins.int

    @property
    def failure(self) -> global___ValidateDatasetFailure: ...

    def __init__(self,
        *,
        failure : typing.Optional[global___ValidateDatasetFailure] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"failure",b"failure"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"failure",b"failure"]) -> None: ...
global___ValidateDatasetResponse = ValidateDatasetResponse

class SqlQueryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    QUERYNAME_FIELD_NUMBER: builtins.int
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    queryName: typing.Text = ...
    dataRoomHash: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        queryName : typing.Optional[typing.Text] = ...,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"queryName",b"queryName"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"queryName",b"queryName"]) -> None: ...
global___SqlQueryRequest = SqlQueryRequest

class SqlQueryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INPROGRESS_FIELD_NUMBER: builtins.int
    FINISHED_FIELD_NUMBER: builtins.int

    @property
    def inProgress(self) -> global___SqlQueryInProgress: ...

    @property
    def finished(self) -> global___SqlQueryFinished: ...

    def __init__(self,
        *,
        inProgress : typing.Optional[global___SqlQueryInProgress] = ...,
        finished : typing.Optional[global___SqlQueryFinished] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"finished",b"finished",u"inProgress",b"inProgress",u"sql_query_response",b"sql_query_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"finished",b"finished",u"inProgress",b"inProgress",u"sql_query_response",b"sql_query_response"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"sql_query_response",b"sql_query_response"]) -> typing_extensions.Literal["inProgress","finished"]: ...
global___SqlQueryResponse = SqlQueryResponse

class SqlQueryInProgress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JOBID_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes = ...

    def __init__(self,
        *,
        jobId : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"jobId",b"jobId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"jobId",b"jobId"]) -> None: ...
global___SqlQueryInProgress = SqlQueryInProgress

class SqlQueryFinished(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    HEADER_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    header: google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text] = ...

    def __init__(self,
        *,
        data : typing.Optional[builtins.bytes] = ...,
        header : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data",b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"header",b"header"]) -> None: ...
global___SqlQueryFinished = SqlQueryFinished

class JobStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JOBID_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        jobId : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"jobId",b"jobId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"jobId",b"jobId"]) -> None: ...
global___JobStatusRequest = JobStatusRequest

class JobStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMPLETED_FIELD_NUMBER: builtins.int
    completed: builtins.bool = ...

    def __init__(self,
        *,
        completed : typing.Optional[builtins.bool] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"completed",b"completed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"completed",b"completed"]) -> None: ...
global___JobStatusResponse = JobStatusResponse

class GetResultsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JOBID_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        jobId : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"jobId",b"jobId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"jobId",b"jobId"]) -> None: ...
global___GetResultsRequest = GetResultsRequest

class RetrieveDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> None: ...
global___RetrieveDataRoomRequest = RetrieveDataRoomRequest

class RetrieveDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOM_FIELD_NUMBER: builtins.int

    @property
    def dataRoom(self) -> data_room_pb2.DataRoom: ...

    def __init__(self,
        *,
        dataRoom : typing.Optional[data_room_pb2.DataRoom] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> None: ...
global___RetrieveDataRoomResponse = RetrieveDataRoomResponse

class RetrieveAuditLogRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> None: ...
global___RetrieveAuditLogRequest = RetrieveAuditLogRequest

class RetrieveAuditLogResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...

    def __init__(self,
        *,
        data : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data",b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data"]) -> None: ...
global___RetrieveAuditLogResponse = RetrieveAuditLogResponse

class RetrieveDataRoomStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> None: ...
global___RetrieveDataRoomStatusRequest = RetrieveDataRoomStatusRequest

class RetrieveDataRoomStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATUS_FIELD_NUMBER: builtins.int
    status: global___DataRoomStatus.V = ...

    def __init__(self,
        *,
        status : typing.Optional[global___DataRoomStatus.V] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"status",b"status"]) -> None: ...
global___RetrieveDataRoomStatusResponse = RetrieveDataRoomStatusResponse

class UpdateDataRoomStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.bytes = ...
    status: global___DataRoomStatus.V = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        status : typing.Optional[global___DataRoomStatus.V] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"status",b"status"]) -> None: ...
global___UpdateDataRoomStatusRequest = UpdateDataRoomStatusRequest

class UpdateDataRoomStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___UpdateDataRoomStatusResponse = UpdateDataRoomStatusResponse

class RetrievePublishedDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    dataRoomHash: builtins.bytes = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash"]) -> None: ...
global___RetrievePublishedDatasetRequest = RetrievePublishedDatasetRequest

class PublishedDataset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TABLE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    DATASET_HASH_FIELD_NUMBER: builtins.int
    table: typing.Text = ...
    user: typing.Text = ...
    timestamp: builtins.int = ...
    dataset_hash: builtins.bytes = ...

    def __init__(self,
        *,
        table : typing.Optional[typing.Text] = ...,
        user : typing.Optional[typing.Text] = ...,
        timestamp : typing.Optional[builtins.int] = ...,
        dataset_hash : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataset_hash",b"dataset_hash",u"table",b"table",u"timestamp",b"timestamp",u"user",b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataset_hash",b"dataset_hash",u"table",b"table",u"timestamp",b"timestamp",u"user",b"user"]) -> None: ...
global___PublishedDataset = PublishedDataset

class RetrievePublishedDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PUBLISHEDDATASETS_FIELD_NUMBER: builtins.int

    @property
    def publishedDatasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PublishedDataset]: ...

    def __init__(self,
        *,
        publishedDatasets : typing.Optional[typing.Iterable[global___PublishedDataset]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"publishedDatasets",b"publishedDatasets"]) -> None: ...
global___RetrievePublishedDatasetResponse = RetrievePublishedDatasetResponse

class RemovePublishedDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MANIFESTHASH_FIELD_NUMBER: builtins.int
    DATAROOMHASH_FIELD_NUMBER: builtins.int
    DATAROOMTABLENAME_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    manifestHash: builtins.bytes = ...
    dataRoomHash: builtins.bytes = ...
    dataRoomTableName: typing.Text = ...

    @property
    def auth(self) -> global___AuthenticationData: ...

    def __init__(self,
        *,
        manifestHash : typing.Optional[builtins.bytes] = ...,
        dataRoomHash : typing.Optional[builtins.bytes] = ...,
        dataRoomTableName : typing.Optional[typing.Text] = ...,
        auth : typing.Optional[global___AuthenticationData] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"dataRoomTableName",b"dataRoomTableName",u"manifestHash",b"manifestHash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth",b"auth",u"dataRoomHash",b"dataRoomHash",u"dataRoomTableName",b"dataRoomTableName",u"manifestHash",b"manifestHash"]) -> None: ...
global___RemovePublishedDatasetRequest = RemovePublishedDatasetRequest

class RemovePublishedDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___RemovePublishedDatasetResponse = RemovePublishedDatasetResponse

class ValidateQueriesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOM_FIELD_NUMBER: builtins.int

    @property
    def dataRoom(self) -> data_room_pb2.DataRoom: ...

    def __init__(self,
        *,
        dataRoom : typing.Optional[data_room_pb2.DataRoom] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> None: ...
global___ValidateQueriesRequest = ValidateQueriesRequest

class QuerySchemas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TABLESCHEMAS_FIELD_NUMBER: builtins.int

    @property
    def tableSchemas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableSchema]: ...

    def __init__(self,
        *,
        tableSchemas : typing.Optional[typing.Iterable[global___TableSchema]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"tableSchemas",b"tableSchemas"]) -> None: ...
global___QuerySchemas = QuerySchemas

class ValidateQueriesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    QUERYSCHEMAS_FIELD_NUMBER: builtins.int
    DATAROOMVALIDATIONERROR_FIELD_NUMBER: builtins.int

    @property
    def querySchemas(self) -> global___QuerySchemas: ...

    @property
    def dataRoomValidationError(self) -> global___DataRoomValidationError: ...

    def __init__(self,
        *,
        querySchemas : typing.Optional[global___QuerySchemas] = ...,
        dataRoomValidationError : typing.Optional[global___DataRoomValidationError] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataRoomValidationError",b"dataRoomValidationError",u"querySchemas",b"querySchemas",u"validate_queries_response",b"validate_queries_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomValidationError",b"dataRoomValidationError",u"querySchemas",b"querySchemas",u"validate_queries_response",b"validate_queries_response"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"validate_queries_response",b"validate_queries_response"]) -> typing_extensions.Literal["querySchemas","dataRoomValidationError"]: ...
global___ValidateQueriesResponse = ValidateQueriesResponse

class EncryptionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MATERIAL_FIELD_NUMBER: builtins.int
    SALT_FIELD_NUMBER: builtins.int
    material: builtins.bytes = ...
    salt: builtins.bytes = ...

    def __init__(self,
        *,
        material : typing.Optional[builtins.bytes] = ...,
        salt : typing.Optional[builtins.bytes] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"material",b"material",u"salt",b"salt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"material",b"material",u"salt",b"salt"]) -> None: ...
global___EncryptionKey = EncryptionKey

class TableSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAMEDCOLUMNS_FIELD_NUMBER: builtins.int

    @property
    def namedColumns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamedColumn]: ...

    def __init__(self,
        *,
        namedColumns : typing.Optional[typing.Iterable[global___NamedColumn]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"namedColumns",b"namedColumns"]) -> None: ...
global___TableSchema = TableSchema

class NamedColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    COLUMNTYPE_FIELD_NUMBER: builtins.int
    name: typing.Text = ...

    @property
    def columnType(self) -> column_type_pb2.ColumnType: ...

    def __init__(self,
        *,
        name : typing.Optional[typing.Text] = ...,
        columnType : typing.Optional[column_type_pb2.ColumnType] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"columnType",b"columnType",u"name",b"name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"columnType",b"columnType",u"name",b"name"]) -> None: ...
global___NamedColumn = NamedColumn

class DatasetManifest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DIGESTHASH_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    digestHash: builtins.bytes = ...

    @property
    def schema(self) -> global___TableSchema: ...

    def __init__(self,
        *,
        digestHash : typing.Optional[builtins.bytes] = ...,
        schema : typing.Optional[global___TableSchema] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"digestHash",b"digestHash",u"schema",b"schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"digestHash",b"digestHash",u"schema",b"schema"]) -> None: ...
global___DatasetManifest = DatasetManifest
